import requests
import xml.etree.ElementTree as ET

try:
    # Python 3
    from urllib.parse import urlparse, urlunparse, urlencode
except ImportError:
    # Python 2
    from urlparse import urlparse, urlunparse
    from urllib import urlencode


class AhsayAPI(object):
    def __init__(self, username, password, hostname):
        self.base_qs = {'SysUser': username, 'SysPwd': password}
        self.base_url = '{host}/obs/api/'.format(
            host=hostname)

    def call(self, action, **kwargs):
        parts = urlparse(self.base_url + action + '.do')
        qs = urlencode(dict(kwargs, **self.base_qs))
        url = urlunparse((parts[0], parts[1], parts[2], parts[3], qs, parts[5]))
        response = requests.get(url)
        root = ET.fromstring(response.text)
        if root.tag == 'err':
            raise Exception(root.text)
        return root



from setuptools import setup
setup(
      name = 'ahsay',
      packages = ['ahsay'], # this must be the same as the name above
      version = '0.2.0',
      description = 'A simple requests wrapper for the Ahsay API',
      author = 'Kristjan Oddsson',
      author_email = 'koddsson@gmail.com',
      url = 'https://github.com/koddsson/ahsay-python-api', # use the URL to the github repo
      download_url = 'https://github.com/koddsson/ahsay-python-api/tarball/0.2.0', # I'll explain this in a second
      keywords = ['ahsay', 'backup', 'api'], # arbitrary keywords
      classifiers = [],
      install_requires = [
        'docopt==0.6.2',
        'requests==2.4.1'
      ],
)



"""Ahsay API example.

Usage:
  example.py <user> <backup_name> [--username=<username> | --password=<password> | --hostname=<hostname>]
  example.py (-h | --help)
  example.py --version

Options:
  -h --help                     Show this screen.
  --version                     Show version.
  --username=<username>         API username
  --password=<password>         API password
  --hostname=<hostname>         API hostname with scheme (https://)

"""
from docopt import docopt

import os

from ahsay.api import AhsayAPI
from datetime import datetime, timedelta


def get_last_backup_time(api, user, backup_name):
    """
    Gets back the datetime of last time the backup schedule ran successfully

    :param user: The user that did the backup.
    :param backup_name: Name of backup file.
    """
    backups = api.call('ListBackupSets', LoginName=user)
    for b in backups:
        if b.attrib['Name'] != backup_name:
            continue
        bs = api.call(
            'GetBackupSet', LoginName=user, BackupSetID=b.attrib['ID'])
        timestamp = int(bs.attrib['LastBackupCompleted'])/1000
        return datetime.fromtimestamp(timestamp)

if __name__ == '__main__':
    arguments = docopt(__doc__, version='Ahsay-API-Example 1.0')
    api_user = arguments.get('--username', None) or os.environ['AHSAY_API_USER']
    api_pass = arguments.get('--password', None) or os.environ['AHSAY_API_PASS']
    api_host = arguments.get('--hostname', None) or os.environ['AHSAY_HOST']
    api = AhsayAPI(api_user, api_pass,  api_host)
    user = arguments['<user>']
    backup_name = arguments['<backup_name>']
    last_backup = get_last_backup_time(api, user, backup_name)

    two_days_ago = datetime.now() - timedelta(days=1)
    if last_backup > two_days_ago:
        print('too old')
